@@ -93,6 +93,12 @@ around 'inject_asset_controllers' => sub {
       include => $share_dir . '/assets/filelink',
       html_head_css_subfiles => ['filelink.css']
     },
+    {
+      controller => 'Assets::RapidApp::FontAwesome',
+      type => 'Directory',
+      include => $share_dir . '/assets/font-awesome',
+      html_head_css_subfiles => ['css/font-awesome.min.css']
+    },
     {
       controller => 'Assets::RapidApp::Misc',
       type => 'Directory',
